#[repr(C)]pub struct EndpointDescriptor {
pub bm_attributes: u8,
pub w_max_packet_size: u16,
pub b_interval: u8,
}Fields
bm_attributes: u8w_max_packet_size: u16The endpoint’s max packet size.
Note: This is expressed in host-endianness, as opposed to the wire descriptors that are always little-endian.
b_interval: u8Trait Implementations
Sourceimpl Clone for EndpointDescriptor
impl Clone for EndpointDescriptor
Sourcefn clone(&self) -> EndpointDescriptor
fn clone(&self) -> EndpointDescriptor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for EndpointDescriptor
Sourceimpl Debug for EndpointDescriptor
impl Debug for EndpointDescriptor
Sourceimpl<D> Decode<EndpointDescriptor, D> for EndpointDescriptorwhere
D: ResourceDialect,
impl<D> Decode<EndpointDescriptor, D> for EndpointDescriptorwhere
D: ResourceDialect,
Sourcefn new_empty() -> EndpointDescriptor
fn new_empty() -> EndpointDescriptor
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<EndpointDescriptor, D> for &EndpointDescriptorwhere
D: ResourceDialect,
impl<D> Encode<EndpointDescriptor, D> for &EndpointDescriptorwhere
D: ResourceDialect,
impl Eq for EndpointDescriptor
Sourceimpl Hash for EndpointDescriptor
impl Hash for EndpointDescriptor
Sourceimpl Ord for EndpointDescriptor
impl Ord for EndpointDescriptor
Sourcefn cmp(&self, other: &EndpointDescriptor) -> Ordering
fn cmp(&self, other: &EndpointDescriptor) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for EndpointDescriptor
impl PartialEq for EndpointDescriptor
Sourcefn eq(&self, other: &EndpointDescriptor) -> bool
fn eq(&self, other: &EndpointDescriptor) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for EndpointDescriptor
impl PartialOrd for EndpointDescriptor
impl Persistable for EndpointDescriptor
impl StructuralPartialEq for EndpointDescriptor
Sourceimpl TypeMarker for EndpointDescriptor
impl TypeMarker for EndpointDescriptor
Sourcetype Owned = EndpointDescriptor
type Owned = EndpointDescriptor
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for EndpointDescriptor
impl ValueTypeMarker for EndpointDescriptor
Sourcetype Borrowed<'a> = &'a EndpointDescriptor
type Borrowed<'a> = &'a EndpointDescriptor
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<EndpointDescriptor as TypeMarker>::Owned,
) -> <EndpointDescriptor as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<EndpointDescriptor as TypeMarker>::Owned, ) -> <EndpointDescriptor as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for EndpointDescriptor
impl RefUnwindSafe for EndpointDescriptor
impl Send for EndpointDescriptor
impl Sync for EndpointDescriptor
impl Unpin for EndpointDescriptor
impl UnsafeUnpin for EndpointDescriptor
impl UnwindSafe for EndpointDescriptor