pub struct UsbFunctionAllocResourcesResponse {
pub interface_nums: Vec<u8>,
pub endpoint_addrs: Vec<u8>,
pub string_indices: Vec<u8>,
}Fields
interface_nums: Vec<u8>endpoint_addrs: Vec<u8>string_indices: Vec<u8>Trait Implementations
Sourceimpl Clone for UsbFunctionAllocResourcesResponse
impl Clone for UsbFunctionAllocResourcesResponse
Sourcefn clone(&self) -> UsbFunctionAllocResourcesResponse
fn clone(&self) -> UsbFunctionAllocResourcesResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D> Decode<UsbFunctionAllocResourcesResponse, D> for UsbFunctionAllocResourcesResponsewhere
D: ResourceDialect,
impl<D> Decode<UsbFunctionAllocResourcesResponse, D> for UsbFunctionAllocResourcesResponsewhere
D: ResourceDialect,
Sourcefn new_empty() -> UsbFunctionAllocResourcesResponse
fn new_empty() -> UsbFunctionAllocResourcesResponse
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<UsbFunctionAllocResourcesResponse, D> for &UsbFunctionAllocResourcesResponsewhere
D: ResourceDialect,
impl<D> Encode<UsbFunctionAllocResourcesResponse, D> for &UsbFunctionAllocResourcesResponsewhere
D: ResourceDialect,
impl Eq for UsbFunctionAllocResourcesResponse
Sourceimpl Ord for UsbFunctionAllocResourcesResponse
impl Ord for UsbFunctionAllocResourcesResponse
Sourcefn cmp(&self, other: &UsbFunctionAllocResourcesResponse) -> Ordering
fn cmp(&self, other: &UsbFunctionAllocResourcesResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for UsbFunctionAllocResourcesResponse
impl PartialEq for UsbFunctionAllocResourcesResponse
Sourcefn eq(&self, other: &UsbFunctionAllocResourcesResponse) -> bool
fn eq(&self, other: &UsbFunctionAllocResourcesResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for UsbFunctionAllocResourcesResponse
impl PartialOrd for UsbFunctionAllocResourcesResponse
impl Persistable for UsbFunctionAllocResourcesResponse
impl StructuralPartialEq for UsbFunctionAllocResourcesResponse
Sourceimpl TypeMarker for UsbFunctionAllocResourcesResponse
impl TypeMarker for UsbFunctionAllocResourcesResponse
Sourcetype Owned = UsbFunctionAllocResourcesResponse
type Owned = UsbFunctionAllocResourcesResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for UsbFunctionAllocResourcesResponse
impl ValueTypeMarker for UsbFunctionAllocResourcesResponse
Sourcetype Borrowed<'a> = &'a UsbFunctionAllocResourcesResponse
type Borrowed<'a> = &'a UsbFunctionAllocResourcesResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<UsbFunctionAllocResourcesResponse as TypeMarker>::Owned,
) -> <UsbFunctionAllocResourcesResponse as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<UsbFunctionAllocResourcesResponse as TypeMarker>::Owned, ) -> <UsbFunctionAllocResourcesResponse as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for UsbFunctionAllocResourcesResponse
impl RefUnwindSafe for UsbFunctionAllocResourcesResponse
impl Send for UsbFunctionAllocResourcesResponse
impl Sync for UsbFunctionAllocResourcesResponse
impl Unpin for UsbFunctionAllocResourcesResponse
impl UnsafeUnpin for UsbFunctionAllocResourcesResponse
impl UnwindSafe for UsbFunctionAllocResourcesResponse