pub struct UsbFunctionConfigureEndpointRequest {
pub endpoint_address: u8,
pub endpoint_configuration: EndpointConfiguration,
}Fields
endpoint_address: u8endpoint_configuration: EndpointConfigurationTrait Implementations
Sourceimpl Clone for UsbFunctionConfigureEndpointRequest
impl Clone for UsbFunctionConfigureEndpointRequest
Sourcefn clone(&self) -> UsbFunctionConfigureEndpointRequest
fn clone(&self) -> UsbFunctionConfigureEndpointRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D> Decode<UsbFunctionConfigureEndpointRequest, D> for UsbFunctionConfigureEndpointRequestwhere
D: ResourceDialect,
impl<D> Decode<UsbFunctionConfigureEndpointRequest, D> for UsbFunctionConfigureEndpointRequestwhere
D: ResourceDialect,
Sourcefn new_empty() -> UsbFunctionConfigureEndpointRequest
fn new_empty() -> UsbFunctionConfigureEndpointRequest
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<UsbFunctionConfigureEndpointRequest, D> for &UsbFunctionConfigureEndpointRequestwhere
D: ResourceDialect,
impl<D> Encode<UsbFunctionConfigureEndpointRequest, D> for &UsbFunctionConfigureEndpointRequestwhere
D: ResourceDialect,
Sourceimpl PartialEq for UsbFunctionConfigureEndpointRequest
impl PartialEq for UsbFunctionConfigureEndpointRequest
Sourcefn eq(&self, other: &UsbFunctionConfigureEndpointRequest) -> bool
fn eq(&self, other: &UsbFunctionConfigureEndpointRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Persistable for UsbFunctionConfigureEndpointRequest
impl StructuralPartialEq for UsbFunctionConfigureEndpointRequest
Sourceimpl TypeMarker for UsbFunctionConfigureEndpointRequest
impl TypeMarker for UsbFunctionConfigureEndpointRequest
Sourcetype Owned = UsbFunctionConfigureEndpointRequest
type Owned = UsbFunctionConfigureEndpointRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for UsbFunctionConfigureEndpointRequest
impl ValueTypeMarker for UsbFunctionConfigureEndpointRequest
Sourcetype Borrowed<'a> = &'a UsbFunctionConfigureEndpointRequest
type Borrowed<'a> = &'a UsbFunctionConfigureEndpointRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<UsbFunctionConfigureEndpointRequest as TypeMarker>::Owned,
) -> <UsbFunctionConfigureEndpointRequest as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<UsbFunctionConfigureEndpointRequest as TypeMarker>::Owned, ) -> <UsbFunctionConfigureEndpointRequest as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for UsbFunctionConfigureEndpointRequest
impl RefUnwindSafe for UsbFunctionConfigureEndpointRequest
impl Send for UsbFunctionConfigureEndpointRequest
impl Sync for UsbFunctionConfigureEndpointRequest
impl Unpin for UsbFunctionConfigureEndpointRequest
impl UnsafeUnpin for UsbFunctionConfigureEndpointRequest
impl UnwindSafe for UsbFunctionConfigureEndpointRequest