pub struct UsbFunctionConfigureRequest {
pub configuration: Vec<u8>,
pub iface: ClientEnd<UsbFunctionInterfaceMarker>,
}Fields
configuration: Vec<u8>iface: ClientEnd<UsbFunctionInterfaceMarker>Trait Implementations
Sourceimpl Debug for UsbFunctionConfigureRequest
impl Debug for UsbFunctionConfigureRequest
Sourceimpl Decode<UsbFunctionConfigureRequest, DefaultFuchsiaResourceDialect> for UsbFunctionConfigureRequest
impl Decode<UsbFunctionConfigureRequest, DefaultFuchsiaResourceDialect> for UsbFunctionConfigureRequest
Sourceimpl Encode<UsbFunctionConfigureRequest, DefaultFuchsiaResourceDialect> for &mut UsbFunctionConfigureRequest
impl Encode<UsbFunctionConfigureRequest, DefaultFuchsiaResourceDialect> for &mut UsbFunctionConfigureRequest
Sourceimpl<T0: Encode<UnboundedVector<u8>, DefaultFuchsiaResourceDialect>, T1: Encode<Endpoint<ClientEnd<UsbFunctionInterfaceMarker>>, DefaultFuchsiaResourceDialect>> Encode<UsbFunctionConfigureRequest, DefaultFuchsiaResourceDialect> for (T0, T1)
impl<T0: Encode<UnboundedVector<u8>, DefaultFuchsiaResourceDialect>, T1: Encode<Endpoint<ClientEnd<UsbFunctionInterfaceMarker>>, DefaultFuchsiaResourceDialect>> Encode<UsbFunctionConfigureRequest, DefaultFuchsiaResourceDialect> for (T0, T1)
impl Eq for UsbFunctionConfigureRequest
Sourceimpl Hash for UsbFunctionConfigureRequest
impl Hash for UsbFunctionConfigureRequest
Sourceimpl Ord for UsbFunctionConfigureRequest
impl Ord for UsbFunctionConfigureRequest
Sourcefn cmp(&self, other: &UsbFunctionConfigureRequest) -> Ordering
fn cmp(&self, other: &UsbFunctionConfigureRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for UsbFunctionConfigureRequest
impl PartialEq for UsbFunctionConfigureRequest
Sourcefn eq(&self, other: &UsbFunctionConfigureRequest) -> bool
fn eq(&self, other: &UsbFunctionConfigureRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for UsbFunctionConfigureRequest
impl PartialOrd for UsbFunctionConfigureRequest
Sourceimpl ResourceTypeMarker for UsbFunctionConfigureRequest
impl ResourceTypeMarker for UsbFunctionConfigureRequest
Sourcetype Borrowed<'a> = &'a mut UsbFunctionConfigureRequest
type Borrowed<'a> = &'a mut UsbFunctionConfigureRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).impl Standalone<DefaultFuchsiaResourceDialect> for UsbFunctionConfigureRequest
impl StructuralPartialEq for UsbFunctionConfigureRequest
Sourceimpl TypeMarker for UsbFunctionConfigureRequest
impl TypeMarker for UsbFunctionConfigureRequest
Sourcetype Owned = UsbFunctionConfigureRequest
type Owned = UsbFunctionConfigureRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Auto Trait Implementations
impl Freeze for UsbFunctionConfigureRequest
impl RefUnwindSafe for UsbFunctionConfigureRequest
impl Send for UsbFunctionConfigureRequest
impl Sync for UsbFunctionConfigureRequest
impl Unpin for UsbFunctionConfigureRequest
impl UnsafeUnpin for UsbFunctionConfigureRequest
impl UnwindSafe for UsbFunctionConfigureRequest