pub struct UsbFunctionConnectToEndpointRequest {
pub ep_addr: u8,
pub ep: ServerEnd<EndpointMarker>,
}Fields
ep_addr: u8ep: ServerEnd<EndpointMarker>Trait Implementations
Sourceimpl Decode<UsbFunctionConnectToEndpointRequest, DefaultFuchsiaResourceDialect> for UsbFunctionConnectToEndpointRequest
impl Decode<UsbFunctionConnectToEndpointRequest, DefaultFuchsiaResourceDialect> for UsbFunctionConnectToEndpointRequest
Sourceimpl Encode<UsbFunctionConnectToEndpointRequest, DefaultFuchsiaResourceDialect> for &mut UsbFunctionConnectToEndpointRequest
impl Encode<UsbFunctionConnectToEndpointRequest, DefaultFuchsiaResourceDialect> for &mut UsbFunctionConnectToEndpointRequest
Sourceimpl<T0: Encode<u8, DefaultFuchsiaResourceDialect>, T1: Encode<Endpoint<ServerEnd<EndpointMarker>>, DefaultFuchsiaResourceDialect>> Encode<UsbFunctionConnectToEndpointRequest, DefaultFuchsiaResourceDialect> for (T0, T1)
impl<T0: Encode<u8, DefaultFuchsiaResourceDialect>, T1: Encode<Endpoint<ServerEnd<EndpointMarker>>, DefaultFuchsiaResourceDialect>> Encode<UsbFunctionConnectToEndpointRequest, DefaultFuchsiaResourceDialect> for (T0, T1)
impl Eq for UsbFunctionConnectToEndpointRequest
Sourceimpl Ord for UsbFunctionConnectToEndpointRequest
impl Ord for UsbFunctionConnectToEndpointRequest
Sourcefn cmp(&self, other: &UsbFunctionConnectToEndpointRequest) -> Ordering
fn cmp(&self, other: &UsbFunctionConnectToEndpointRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for UsbFunctionConnectToEndpointRequest
impl PartialEq for UsbFunctionConnectToEndpointRequest
Sourcefn eq(&self, other: &UsbFunctionConnectToEndpointRequest) -> bool
fn eq(&self, other: &UsbFunctionConnectToEndpointRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for UsbFunctionConnectToEndpointRequest
impl PartialOrd for UsbFunctionConnectToEndpointRequest
Sourceimpl ResourceTypeMarker for UsbFunctionConnectToEndpointRequest
impl ResourceTypeMarker for UsbFunctionConnectToEndpointRequest
Sourcetype Borrowed<'a> = &'a mut UsbFunctionConnectToEndpointRequest
type Borrowed<'a> = &'a mut UsbFunctionConnectToEndpointRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).impl Standalone<DefaultFuchsiaResourceDialect> for UsbFunctionConnectToEndpointRequest
impl StructuralPartialEq for UsbFunctionConnectToEndpointRequest
Sourceimpl TypeMarker for UsbFunctionConnectToEndpointRequest
impl TypeMarker for UsbFunctionConnectToEndpointRequest
Sourcetype Owned = UsbFunctionConnectToEndpointRequest
type Owned = UsbFunctionConnectToEndpointRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Auto Trait Implementations
impl Freeze for UsbFunctionConnectToEndpointRequest
impl RefUnwindSafe for UsbFunctionConnectToEndpointRequest
impl Send for UsbFunctionConnectToEndpointRequest
impl Sync for UsbFunctionConnectToEndpointRequest
impl Unpin for UsbFunctionConnectToEndpointRequest
impl UnsafeUnpin for UsbFunctionConnectToEndpointRequest
impl UnwindSafe for UsbFunctionConnectToEndpointRequest