#[repr(C)]pub struct UsbFunctionEndpointSetStallRequest {
pub endpoint_address: u8,
}Fields
endpoint_address: u8Trait Implementations
Sourceimpl Clone for UsbFunctionEndpointSetStallRequest
impl Clone for UsbFunctionEndpointSetStallRequest
Sourcefn clone(&self) -> UsbFunctionEndpointSetStallRequest
fn clone(&self) -> UsbFunctionEndpointSetStallRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for UsbFunctionEndpointSetStallRequest
Sourceimpl<D> Decode<UsbFunctionEndpointSetStallRequest, D> for UsbFunctionEndpointSetStallRequestwhere
D: ResourceDialect,
impl<D> Decode<UsbFunctionEndpointSetStallRequest, D> for UsbFunctionEndpointSetStallRequestwhere
D: ResourceDialect,
Sourcefn new_empty() -> UsbFunctionEndpointSetStallRequest
fn new_empty() -> UsbFunctionEndpointSetStallRequest
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<UsbFunctionEndpointSetStallRequest, D> for &UsbFunctionEndpointSetStallRequestwhere
D: ResourceDialect,
impl<D> Encode<UsbFunctionEndpointSetStallRequest, D> for &UsbFunctionEndpointSetStallRequestwhere
D: ResourceDialect,
impl Eq for UsbFunctionEndpointSetStallRequest
Sourceimpl Ord for UsbFunctionEndpointSetStallRequest
impl Ord for UsbFunctionEndpointSetStallRequest
Sourcefn cmp(&self, other: &UsbFunctionEndpointSetStallRequest) -> Ordering
fn cmp(&self, other: &UsbFunctionEndpointSetStallRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for UsbFunctionEndpointSetStallRequest
impl PartialEq for UsbFunctionEndpointSetStallRequest
Sourcefn eq(&self, other: &UsbFunctionEndpointSetStallRequest) -> bool
fn eq(&self, other: &UsbFunctionEndpointSetStallRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for UsbFunctionEndpointSetStallRequest
impl PartialOrd for UsbFunctionEndpointSetStallRequest
impl Persistable for UsbFunctionEndpointSetStallRequest
impl StructuralPartialEq for UsbFunctionEndpointSetStallRequest
Sourceimpl TypeMarker for UsbFunctionEndpointSetStallRequest
impl TypeMarker for UsbFunctionEndpointSetStallRequest
Sourcetype Owned = UsbFunctionEndpointSetStallRequest
type Owned = UsbFunctionEndpointSetStallRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for UsbFunctionEndpointSetStallRequest
impl ValueTypeMarker for UsbFunctionEndpointSetStallRequest
Sourcetype Borrowed<'a> = &'a UsbFunctionEndpointSetStallRequest
type Borrowed<'a> = &'a UsbFunctionEndpointSetStallRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<UsbFunctionEndpointSetStallRequest as TypeMarker>::Owned,
) -> <UsbFunctionEndpointSetStallRequest as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<UsbFunctionEndpointSetStallRequest as TypeMarker>::Owned, ) -> <UsbFunctionEndpointSetStallRequest as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for UsbFunctionEndpointSetStallRequest
impl RefUnwindSafe for UsbFunctionEndpointSetStallRequest
impl Send for UsbFunctionEndpointSetStallRequest
impl Sync for UsbFunctionEndpointSetStallRequest
impl Unpin for UsbFunctionEndpointSetStallRequest
impl UnsafeUnpin for UsbFunctionEndpointSetStallRequest
impl UnwindSafe for UsbFunctionEndpointSetStallRequest