pub struct UsbFunctionInterfaceMarker;Trait Implementations
Sourceimpl Clone for UsbFunctionInterfaceMarker
impl Clone for UsbFunctionInterfaceMarker
Sourcefn clone(&self) -> UsbFunctionInterfaceMarker
fn clone(&self) -> UsbFunctionInterfaceMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for UsbFunctionInterfaceMarker
Sourceimpl Debug for UsbFunctionInterfaceMarker
impl Debug for UsbFunctionInterfaceMarker
impl Eq for UsbFunctionInterfaceMarker
Sourceimpl Hash for UsbFunctionInterfaceMarker
impl Hash for UsbFunctionInterfaceMarker
Sourceimpl Ord for UsbFunctionInterfaceMarker
impl Ord for UsbFunctionInterfaceMarker
Sourcefn cmp(&self, other: &UsbFunctionInterfaceMarker) -> Ordering
fn cmp(&self, other: &UsbFunctionInterfaceMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for UsbFunctionInterfaceMarker
impl PartialEq for UsbFunctionInterfaceMarker
Sourcefn eq(&self, other: &UsbFunctionInterfaceMarker) -> bool
fn eq(&self, other: &UsbFunctionInterfaceMarker) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for UsbFunctionInterfaceMarker
impl PartialOrd for UsbFunctionInterfaceMarker
Sourceimpl ProtocolMarker for UsbFunctionInterfaceMarker
impl ProtocolMarker for UsbFunctionInterfaceMarker
Sourceconst DEBUG_NAME: &'static str = "(anonymous) UsbFunctionInterface"
const DEBUG_NAME: &'static str = "(anonymous) UsbFunctionInterface"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = UsbFunctionInterfaceProxy
type Proxy = UsbFunctionInterfaceProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = UsbFunctionInterfaceRequestStream
type RequestStream = UsbFunctionInterfaceRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = UsbFunctionInterfaceSynchronousProxy
type SynchronousProxy = UsbFunctionInterfaceSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl StructuralPartialEq for UsbFunctionInterfaceMarker