#[repr(C)]pub struct UsbFunctionInterfaceSetInterfaceRequest {
pub interface: u8,
pub alt_setting: u8,
}Fields
interface: u8alt_setting: u8Trait Implementations
Sourceimpl Clone for UsbFunctionInterfaceSetInterfaceRequest
impl Clone for UsbFunctionInterfaceSetInterfaceRequest
Sourcefn clone(&self) -> UsbFunctionInterfaceSetInterfaceRequest
fn clone(&self) -> UsbFunctionInterfaceSetInterfaceRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for UsbFunctionInterfaceSetInterfaceRequest
Sourceimpl<D> Decode<UsbFunctionInterfaceSetInterfaceRequest, D> for UsbFunctionInterfaceSetInterfaceRequestwhere
D: ResourceDialect,
impl<D> Decode<UsbFunctionInterfaceSetInterfaceRequest, D> for UsbFunctionInterfaceSetInterfaceRequestwhere
D: ResourceDialect,
Sourcefn new_empty() -> UsbFunctionInterfaceSetInterfaceRequest
fn new_empty() -> UsbFunctionInterfaceSetInterfaceRequest
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<UsbFunctionInterfaceSetInterfaceRequest, D> for &UsbFunctionInterfaceSetInterfaceRequestwhere
D: ResourceDialect,
impl<D> Encode<UsbFunctionInterfaceSetInterfaceRequest, D> for &UsbFunctionInterfaceSetInterfaceRequestwhere
D: ResourceDialect,
impl Eq for UsbFunctionInterfaceSetInterfaceRequest
Sourceimpl Ord for UsbFunctionInterfaceSetInterfaceRequest
impl Ord for UsbFunctionInterfaceSetInterfaceRequest
Sourcefn cmp(&self, other: &UsbFunctionInterfaceSetInterfaceRequest) -> Ordering
fn cmp(&self, other: &UsbFunctionInterfaceSetInterfaceRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for UsbFunctionInterfaceSetInterfaceRequest
impl PartialEq for UsbFunctionInterfaceSetInterfaceRequest
Sourcefn eq(&self, other: &UsbFunctionInterfaceSetInterfaceRequest) -> bool
fn eq(&self, other: &UsbFunctionInterfaceSetInterfaceRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for UsbFunctionInterfaceSetInterfaceRequest
impl PartialOrd for UsbFunctionInterfaceSetInterfaceRequest
impl Persistable for UsbFunctionInterfaceSetInterfaceRequest
impl StructuralPartialEq for UsbFunctionInterfaceSetInterfaceRequest
Sourceimpl TypeMarker for UsbFunctionInterfaceSetInterfaceRequest
impl TypeMarker for UsbFunctionInterfaceSetInterfaceRequest
Sourcetype Owned = UsbFunctionInterfaceSetInterfaceRequest
type Owned = UsbFunctionInterfaceSetInterfaceRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for UsbFunctionInterfaceSetInterfaceRequest
impl ValueTypeMarker for UsbFunctionInterfaceSetInterfaceRequest
Sourcetype Borrowed<'a> = &'a UsbFunctionInterfaceSetInterfaceRequest
type Borrowed<'a> = &'a UsbFunctionInterfaceSetInterfaceRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<UsbFunctionInterfaceSetInterfaceRequest as TypeMarker>::Owned,
) -> <UsbFunctionInterfaceSetInterfaceRequest as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<UsbFunctionInterfaceSetInterfaceRequest as TypeMarker>::Owned, ) -> <UsbFunctionInterfaceSetInterfaceRequest as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for UsbFunctionInterfaceSetInterfaceRequest
impl RefUnwindSafe for UsbFunctionInterfaceSetInterfaceRequest
impl Send for UsbFunctionInterfaceSetInterfaceRequest
impl Sync for UsbFunctionInterfaceSetInterfaceRequest
impl Unpin for UsbFunctionInterfaceSetInterfaceRequest
impl UnsafeUnpin for UsbFunctionInterfaceSetInterfaceRequest
impl UnwindSafe for UsbFunctionInterfaceSetInterfaceRequest