pub struct UsbFunctionMarker;Trait Implementations
Sourceimpl Clone for UsbFunctionMarker
impl Clone for UsbFunctionMarker
Sourcefn clone(&self) -> UsbFunctionMarker
fn clone(&self) -> UsbFunctionMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for UsbFunctionMarker
Sourceimpl Debug for UsbFunctionMarker
impl Debug for UsbFunctionMarker
Sourceimpl DiscoverableProtocolMarker for UsbFunctionMarker
impl DiscoverableProtocolMarker for UsbFunctionMarker
Sourceconst PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
const PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
The name of the protocol (to be used for service lookup and discovery).
impl Eq for UsbFunctionMarker
Sourceimpl Hash for UsbFunctionMarker
impl Hash for UsbFunctionMarker
Sourceimpl Ord for UsbFunctionMarker
impl Ord for UsbFunctionMarker
Sourcefn cmp(&self, other: &UsbFunctionMarker) -> Ordering
fn cmp(&self, other: &UsbFunctionMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for UsbFunctionMarker
impl PartialEq for UsbFunctionMarker
Sourcefn eq(&self, other: &UsbFunctionMarker) -> bool
fn eq(&self, other: &UsbFunctionMarker) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for UsbFunctionMarker
impl PartialOrd for UsbFunctionMarker
Sourceimpl ProtocolMarker for UsbFunctionMarker
impl ProtocolMarker for UsbFunctionMarker
Sourceconst DEBUG_NAME: &'static str = "fuchsia.hardware.usb.function.UsbFunction"
const DEBUG_NAME: &'static str = "fuchsia.hardware.usb.function.UsbFunction"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = UsbFunctionProxy
type Proxy = UsbFunctionProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = UsbFunctionRequestStream
type RequestStream = UsbFunctionRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = UsbFunctionSynchronousProxy
type SynchronousProxy = UsbFunctionSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl StructuralPartialEq for UsbFunctionMarker