pub struct UsbFunctionServiceMarker;Trait Implementations
Sourceimpl Clone for UsbFunctionServiceMarker
impl Clone for UsbFunctionServiceMarker
Sourcefn clone(&self) -> UsbFunctionServiceMarker
fn clone(&self) -> UsbFunctionServiceMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for UsbFunctionServiceMarker
Sourceimpl Debug for UsbFunctionServiceMarker
impl Debug for UsbFunctionServiceMarker
impl Eq for UsbFunctionServiceMarker
Sourceimpl Hash for UsbFunctionServiceMarker
impl Hash for UsbFunctionServiceMarker
Sourceimpl Ord for UsbFunctionServiceMarker
impl Ord for UsbFunctionServiceMarker
Sourcefn cmp(&self, other: &UsbFunctionServiceMarker) -> Ordering
fn cmp(&self, other: &UsbFunctionServiceMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for UsbFunctionServiceMarker
impl PartialEq for UsbFunctionServiceMarker
Sourcefn eq(&self, other: &UsbFunctionServiceMarker) -> bool
fn eq(&self, other: &UsbFunctionServiceMarker) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for UsbFunctionServiceMarker
impl PartialOrd for UsbFunctionServiceMarker
Sourceimpl ServiceMarker for UsbFunctionServiceMarker
Available on Fuchsia only.
impl ServiceMarker for UsbFunctionServiceMarker
Available on Fuchsia only.
Sourceconst SERVICE_NAME: &'static str = "fuchsia.hardware.usb.function.UsbFunctionService"
const SERVICE_NAME: &'static str = "fuchsia.hardware.usb.function.UsbFunctionService"
The name of the service. Used for service lookup and discovery.
Sourcetype Proxy = UsbFunctionServiceProxy
type Proxy = UsbFunctionServiceProxy
The type of the proxy object upon which calls are made to a remote FIDL service.
Sourcetype Request = UsbFunctionServiceRequest
type Request = UsbFunctionServiceRequest
The request type for this particular FIDL service.
impl StructuralPartialEq for UsbFunctionServiceMarker